==> apo_0.1.5.tar.gz: apoinstall/index.php <==
<?php
	// Configuration de APO
	$apoDir = dirname(__FILE__);
	$apoFile = basename(__FILE__);
	
	// On vérifie que le site est bien installé en regardant si config.ini existe
	if(!is_file($apoDir."/config/config.ini")){
		// Le fichier n'existe pas, on redirige vers l'installation
		header("Location: install/");
		exit;
	}
	
	// Configuration
	require $apoDir."/config/config.php";
	
	// Instanciation de Apo
	$apo = new Apo($apoDir, $apoFile, $connApo);
	
	// Configuration
	$apo->config = $apoDir."/config/config.ini";
	
	// Authentification
	$apo->login();
	
	// Vérification de la validité de la page
	$apo->page = FormUtils::getParam("p");
	
	// Fichier d'action de la page
	if($apo->pageActionPath){
		include $apo->pageActionPath;
	}
	
	// Fichier de script de la page
	if($apo->pageScriptPath){
		include $apo->pageScriptPath;
	}
	
	// Affichage du HTML
	// Envoi des en-tête HTTP
	// if(strrpos($_SERVER["HTTP_USER_AGENT"], "MSIE"))
	$accept_xml = !empty($_SERVER['HTTP_ACCEPT']) && strpos($_SERVER['HTTP_ACCEPT'],'application/xhtml+xml') !== false;
	if ($accept_xml) {
		header('Content-Type: application/xhtml+xml');
	} else {
		header('Content-Type: text/html; charset=UTF-8');
	}
	
	if ($accept_xml) {
		echo '<?xml version="1.0" encoding="UTF-8"?>'."\n";
	}
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $apo->lang; ?>" lang="<?php echo $apo->lang; ?>">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
		<meta http-equiv="Content-Style-Type" content="text/css" />
		<link rel="stylesheet" type="text/css" href="themes/<?php echo $apo->theme; ?>/style.css" />
		<title>APO - <?php echo $apo->pageTitle; ?></title>
		<script type="text/javascript" src="js/functions.js"></script>
	</head>
	<body>
		<?php echo $apo->error; ?>
		<?php echo $apo->message; ?>
		<?php 
			if($apo->pagePath){
				include $apo->pagePath; 
			}
		?>
		<div id="footer">
			<a href="http://www.neolao.com" hreflang="fr" title="Site principal de neolao"><img src="themes/<?php echo $apo->theme; ?>/images/button-neolao.png" alt="Site principal de neolao" /></a>
			<a href="http://creativecommons.org/licenses/by-nc-sa/2.0/fr/" rel="license" title="License Creative Commons"><img src="themes/<?php echo $apo->theme; ?>/images/button-cc.gif" alt="License Creative Commons" /></a>
		</div>
	</body>
</html>

==> apo_0.2.0.tar.gz: apoinstall/index.php <==
<?php
	// Configuration de APO
	$apoDir = dirname(__FILE__);
	$apoFile = basename(__FILE__);
	
	// On vérifie que le site est bien installé en regardant si config.ini existe
	if(!is_file($apoDir."/config/config.ini")){
		// Le fichier n'existe pas, on redirige vers l'installation
		header("Location: install/");
		exit;
	}
	
	// Configuration
	require $apoDir."/config/config.php";
	
	// Instanciation de Apo
	$apo = new Apo($apoDir, $apoFile, $connApo);
	
	// Configuration
	$apo->config = $apoDir."/config/config.ini";
	
	// Authentification
	$apo->login();
	
	// Vérification de la validité de la page
	$apo->page = FormUtils::getParam("p");
	
	// Fichier d'action de la page
	if($apo->pageActionPath){
		include $apo->pageActionPath;
	}
	
	// Fichier de script de la page
	if($apo->pageScriptPath){
		include $apo->pageScriptPath;
	}
	
	// Affichage du HTML
	// Envoi des en-tête HTTP
	// if(strrpos($_SERVER["HTTP_USER_AGENT"], "MSIE"))
	$accept_xml = !empty($_SERVER['HTTP_ACCEPT']) && strpos($_SERVER['HTTP_ACCEPT'],'application/xhtml+xml') !== false;
	if ($accept_xml) {
		header('Content-Type: application/xhtml+xml');
	} else {
		header('Content-Type: text/html; charset=UTF-8');
	}
	
	if ($accept_xml) {
		echo '<?xml version="1.0" encoding="UTF-8"?>'."\n";
	}
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $apo->lang; ?>" lang="<?php echo $apo->lang; ?>">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
		<meta http-equiv="Content-Style-Type" content="text/css" />
		<link rel="stylesheet" type="text/css" href="themes/<?php echo $apo->theme; ?>/style.css" />
		<title>APO - <?php echo $apo->pageTitle; ?></title>
		<script type="text/javascript" src="js/functions.js"></script>
	</head>
	<body>
		<?php echo $apo->error; ?>
		<?php echo $apo->message; ?>
		<?php 
			if($apo->pagePath){
				include $apo->pagePath; 
			}
		?>
		<div id="footer">
			<a href="http://www.neolao.com" title="neolao.com"><img src="themes/<?php echo $apo->theme; ?>/images/button-neolao.png" alt="neolao.com" /></a>
			<a href="http://creativecommons.org/licenses/by-nc-sa/2.0/" rel="license" title="License Creative Commons"><img src="themes/<?php echo $apo->theme; ?>/images/button-cc.gif" alt="License Creative Commons" /></a>
		</div>
	</body>
</html>
